Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(581)

Unified Diff: net/http/http_server_properties_manager.h

Issue 1043973002: Introduce AlternativeServiceInfo. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Early return. Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/http/http_server_properties_impl_unittest.cc ('k') | net/http/http_server_properties_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/http/http_server_properties_manager.h
diff --git a/net/http/http_server_properties_manager.h b/net/http/http_server_properties_manager.h
index db4dfb641cddd47cfb6ffbae97a167ef13b087a4..8223c9e4baabfd06d136d54e502ebbc9699be961 100644
--- a/net/http/http_server_properties_manager.h
+++ b/net/http/http_server_properties_manager.h
@@ -101,7 +101,7 @@ class NET_EXPORT HttpServerPropertiesManager : public HttpServerProperties {
void ConfirmAlternativeService(
const AlternativeService& alternative_service) override;
void ClearAlternativeService(const HostPortPair& origin) override;
- const AlternateProtocolMap& alternate_protocol_map() const override;
+ const AlternativeServiceMap& alternative_service_map() const override;
void SetAlternateProtocolProbabilityThreshold(double threshold) override;
const SettingsMap& GetSpdySettings(
const HostPortPair& host_port_pair) override;
@@ -145,14 +145,14 @@ class NET_EXPORT HttpServerPropertiesManager : public HttpServerProperties {
void UpdateCacheFromPrefsOnNetworkThread(
std::vector<std::string>* spdy_servers,
SpdySettingsMap* spdy_settings_map,
- AlternateProtocolMap* alternate_protocol_map,
+ AlternativeServiceMap* alternative_service_map,
IPAddressNumber* last_quic_address,
ServerNetworkStatsMap* server_network_stats_map,
bool detected_corrupted_prefs);
// These are used to delay updating the preferences when cached data in
// |http_server_properties_impl_| is changing, and execute only one update per
// simultaneous spdy_servers or spdy_settings or alternate_protocol changes.
void ScheduleUpdatePrefsOnNetworkThread();
// Starts the timers to update the prefs from cache. This are overridden in
@@ -174,7 +174,7 @@ class NET_EXPORT HttpServerPropertiesManager : public HttpServerProperties {
// optional |completion| callback when finished. Protected for testing.
void UpdatePrefsOnPrefThread(base::ListValue* spdy_server_list,
SpdySettingsMap* spdy_settings_map,
- AlternateProtocolMap* alternate_protocol_map,
+ AlternativeServiceMap* alternative_service_map,
IPAddressNumber* last_quic_address,
ServerNetworkStatsMap* server_network_stats_map,
const base::Closure& completion);
@@ -187,20 +187,21 @@ class NET_EXPORT HttpServerPropertiesManager : public HttpServerProperties {
void AddToSpdySettingsMap(const HostPortPair& server,
const base::DictionaryValue& server_dict,
SpdySettingsMap* spdy_settings_map);
- AlternateProtocolInfo ParseAlternateProtocolDict(
- const base::DictionaryValue& alternate_protocol_dict,
+ AlternativeServiceInfo ParseAlternativeServiceDict(
+ const base::DictionaryValue& alternative_service_dict,
const std::string& server_str);
- bool AddToAlternateProtocolMap(const HostPortPair& server,
- const base::DictionaryValue& server_dict,
- AlternateProtocolMap* alternate_protocol_map);
+ bool AddToAlternativeServiceMap(
+ const HostPortPair& server,
+ const base::DictionaryValue& server_dict,
+ AlternativeServiceMap* alternative_service_map);
bool AddToNetworkStatsMap(const HostPortPair& server,
const base::DictionaryValue& server_dict,
ServerNetworkStatsMap* network_stats_map);
void SaveSpdySettingsToServerPrefs(const SettingsMap* spdy_settings_map,
base::DictionaryValue* server_pref_dict);
- void SaveAlternateProtocolToServerPrefs(
- const AlternateProtocolInfo* port_alternate_protocol,
+ void SaveAlternativeServiceToServerPrefs(
+ const AlternativeServiceInfo* alternative_service_info,
base::DictionaryValue* server_pref_dict);
void SaveNetworkStatsToServerPrefs(
const ServerNetworkStats* server_network_stats,
@@ -145,14 +145,14 @@ class NET_EXPORT HttpServerPropertiesManager : public HttpServerProperties {
// These are used to delay updating the preferences when cached data in
// |http_server_properties_impl_| is changing, and execute only one update per
- // simultaneous spdy_servers or spdy_settings or alternate_protocol changes.
+ // simultaneous spdy_servers or spdy_settings or alternative_service changes.
void ScheduleUpdatePrefsOnNetworkThread();
// Starts the timers to update the prefs from cache. This are overridden in
« no previous file with comments | « net/http/http_server_properties_impl_unittest.cc ('k') | net/http/http_server_properties_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698